[libcitygml] 01/04: New upstream version 2.0.8

Bas Couwenberg sebastic at debian.org
Tue Dec 19 22:58:27 UTC 2017


This is an automated email from the git hooks/post-receive script.

sebastic pushed a commit to branch master
in repository libcitygml.

commit 2bf1ef9b40a97d69929e05877224d513e0f3eec9
Author: Bas Couwenberg <sebastic at xs4all.nl>
Date:   Tue Dec 19 23:38:02 2017 +0100

    New upstream version 2.0.8
---
 CMakeLists.txt                                     |  2 +-
 sources/include/citygml/appearancemanager.h        |  2 +-
 sources/include/citygml/appearancetarget.h         |  2 +-
 .../include/citygml/appearancetargetdefinition.h   |  2 +-
 sources/include/citygml/attributesmap.h            |  4 ++--
 sources/include/citygml/citygml.h                  |  2 +-
 sources/include/citygml/citygmlfactory.h           |  2 +-
 sources/include/citygml/citymodel.h                |  2 +-
 sources/include/citygml/cityobject.h               | 24 +++++++++-------------
 sources/include/citygml/enum_type_bitmask.h        | 20 ++++++++++--------
 sources/include/citygml/envelope.h                 |  2 +-
 sources/include/citygml/featureobject.h            |  2 +-
 sources/include/citygml/geometry.h                 |  2 +-
 sources/include/citygml/geometrymanager.h          |  4 +++-
 sources/include/citygml/implictgeometry.h          |  2 +-
 sources/include/citygml/object.h                   |  2 +-
 sources/include/citygml/polygonmanager.h           |  4 +++-
 sources/include/citygml/tesselator.h               |  3 ++-
 sources/include/citygml/texture.h                  |  8 ++++----
 sources/include/citygml/texturecoordinates.h       |  2 +-
 sources/include/citygml/transformmatrix.h          |  2 +-
 21 files changed, 49 insertions(+), 46 deletions(-)

diff --git a/CMakeLists.txt b/CMakeLists.txt
index d879f90..f3d5f92 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -4,7 +4,7 @@ PROJECT ( libcitygml )
 
 set(META_VERSION_MAJOR       "2")
 set(META_VERSION_MINOR       "0")
-set(META_VERSION_PATCH       "7")
+set(META_VERSION_PATCH       "8")
 
 set(META_VERSION             "${META_VERSION_MAJOR}.${META_VERSION_MINOR}.${META_VERSION_PATCH}")
 
diff --git a/sources/include/citygml/appearancemanager.h b/sources/include/citygml/appearancemanager.h
index 926f898..4c4e973 100644
--- a/sources/include/citygml/appearancemanager.h
+++ b/sources/include/citygml/appearancemanager.h
@@ -21,7 +21,7 @@ namespace citygml {
     class TextureTargetDefinition;
 
 
-    class AppearanceManager
+    class LIBCITYGML_EXPORT AppearanceManager
     {
     public:
         AppearanceManager(std::shared_ptr<CityGMLLogger> logger );
diff --git a/sources/include/citygml/appearancetarget.h b/sources/include/citygml/appearancetarget.h
index 1269c36..cb551d4 100644
--- a/sources/include/citygml/appearancetarget.h
+++ b/sources/include/citygml/appearancetarget.h
@@ -19,7 +19,7 @@ namespace citygml {
      *
      * Ensures that there is only one texture and material per theme
      */
-    class AppearanceTarget : public citygml::Object {
+    class LIBCITYGML_EXPORT AppearanceTarget : public citygml::Object {
     public:
 
         void addTargetDefinition(std::shared_ptr<AppearanceTargetDefinition<Appearance> > targetDef);
diff --git a/sources/include/citygml/appearancetargetdefinition.h b/sources/include/citygml/appearancetargetdefinition.h
index 02b699d..b491c4c 100644
--- a/sources/include/citygml/appearancetargetdefinition.h
+++ b/sources/include/citygml/appearancetargetdefinition.h
@@ -23,7 +23,7 @@ namespace citygml {
      * @brief defines the association between an Appearance object and an AppearanceTarget object
      */
     template<class T>
-    class AppearanceTargetDefinition : public Object {
+    class LIBCITYGML_EXPORT AppearanceTargetDefinition : public Object {
     public:
         AppearanceTargetDefinition(const std::string& targetID, std::shared_ptr<T> appearance, const std::string& id) : Object(id), m_targetID(targetID), m_appearance(appearance) {}
 
diff --git a/sources/include/citygml/attributesmap.h b/sources/include/citygml/attributesmap.h
index c8eaa41..c967566 100644
--- a/sources/include/citygml/attributesmap.h
+++ b/sources/include/citygml/attributesmap.h
@@ -31,7 +31,7 @@ public:
     AttributeValue(const std::string& value, AttributeType type=AttributeType::String);
     AttributeValue(double value);
     AttributeValue(int value);
-    
+
 
     void setType(AttributeType type);
     AttributeType getType() const;
@@ -48,7 +48,7 @@ private:
     std::string m_value;
 };
 
-std::ostream& operator<<(std::ostream& os, const AttributeValue& o);
+LIBCITYGML_EXPORT std::ostream& operator<<(std::ostream& os, const AttributeValue& o);
 
 typedef std::map<std::string, AttributeValue> AttributesMap;
 
diff --git a/sources/include/citygml/citygml.h b/sources/include/citygml/citygml.h
index e9e6c92..41c9736 100644
--- a/sources/include/citygml/citygml.h
+++ b/sources/include/citygml/citygml.h
@@ -60,7 +60,7 @@ namespace citygml
     // tesselate: convert the interior & exteriors polygons to triangles
     // destSRS: the SRS (WKT, EPSG, OGC URN, etc.) where the coordinates must be transformed, default ("") is no transformation
 
-    class ParserParams
+    class LIBCITYGML_EXPORT ParserParams
     {
     public:
         ParserParams()
diff --git a/sources/include/citygml/citygmlfactory.h b/sources/include/citygml/citygmlfactory.h
index 8bd3357..2d97ca6 100644
--- a/sources/include/citygml/citygmlfactory.h
+++ b/sources/include/citygml/citygmlfactory.h
@@ -28,7 +28,7 @@ namespace citygml {
     class MaterialTargetDefinition;
     class TextureTargetDefinition;
 
-    class CityGMLFactory {
+    class LIBCITYGML_EXPORT CityGMLFactory {
     public:
         CityGMLFactory(std::shared_ptr<CityGMLLogger> logger);
 
diff --git a/sources/include/citygml/citymodel.h b/sources/include/citygml/citymodel.h
index 760c893..4a28e35 100644
--- a/sources/include/citygml/citymodel.h
+++ b/sources/include/citygml/citymodel.h
@@ -61,5 +61,5 @@ namespace citygml {
         std::vector<std::string> m_themes;
     };
 
-    std::ostream& operator<<( std::ostream&, const citygml::CityModel & );
+    LIBCITYGML_EXPORT std::ostream& operator<<( std::ostream&, const citygml::CityModel & );
 }
diff --git a/sources/include/citygml/cityobject.h b/sources/include/citygml/cityobject.h
index 0b0e01c..58d882e 100644
--- a/sources/include/citygml/cityobject.h
+++ b/sources/include/citygml/cityobject.h
@@ -40,10 +40,10 @@ namespace citygml {
             COT_WaterBody                   = 1ll<< 14,
             COT_ReliefFeature               = 1ll<< 15,
             COT_LandUse                     = 1ll<< 16,
-            COT_Tunnel						= 1ll<< 17,
-            COT_Bridge						= 1ll<< 18,
-            COT_BridgeConstructionElement	= 1ll<< 19,
-            COT_BridgeInstallation			= 1ll<< 20,
+            COT_Tunnel                      = 1ll<< 17,
+            COT_Bridge                      = 1ll<< 18,
+            COT_BridgeConstructionElement   = 1ll<< 19,
+            COT_BridgeInstallation          = 1ll<< 20,
             COT_BridgePart                  = 1ll<< 21,
             COT_BuildingPart                = 1ll<< 22,
 
@@ -57,7 +57,7 @@ namespace citygml {
             COT_CityObjectGroup             = 1ll<< 30,
             COT_OuterCeilingSurface         = 1ll<< 31,
             COT_OuterFloorSurface           = 1ll<< 32,
-            
+
 
             // covers all supertypes of tran::_TransportationObject that are not Track, Road, Railway or Square...
             // there are to many for to few bits to explicitly enumerate them. However Track, Road, Railway or Square should be used most of the time
@@ -65,9 +65,7 @@ namespace citygml {
 
             COT_All                         = 0xFFFFFFFFFFFFFFFFll
         };
-        
-        
-        
+
         CityObject( const std::string& id, CityObjectsType type );
 
         // Get the object type
@@ -116,13 +114,11 @@ namespace citygml {
         std::unique_ptr<Address> m_address;
     };
 
-    std::ostream& operator<<( std::ostream& os, const CityObject& o );
+    LIBCITYGML_EXPORT std::ostream& operator<<( std::ostream& os, const CityObject& o );
+
+    LIBCITYGML_EXPORT std::string cityObjectsTypeToString(const CityObject::CityObjectsType& t);
+    LIBCITYGML_EXPORT CityObject::CityObjectsType cityObjectsTypeFromString(const std::string& s, bool& valid);
 
-    std::string cityObjectsTypeToString(const CityObject::CityObjectsType& t);
-    CityObject::CityObjectsType cityObjectsTypeFromString(const std::string& s, bool& valid);
-    
-    
-    
 }
 
 ENUM_CLASS_BITWISE_OPERATORS_DEFS(citygml::CityObject::CityObjectsType);
diff --git a/sources/include/citygml/envelope.h b/sources/include/citygml/envelope.h
index 1c09247..8d46348 100644
--- a/sources/include/citygml/envelope.h
+++ b/sources/include/citygml/envelope.h
@@ -41,5 +41,5 @@ namespace citygml {
         std::string m_srsName;
     };
 
-    std::ostream& operator<<( std::ostream&, const citygml::Envelope& );
+    LIBCITYGML_EXPORT std::ostream& operator<<( std::ostream&, const citygml::Envelope& );
 }
diff --git a/sources/include/citygml/featureobject.h b/sources/include/citygml/featureobject.h
index 35d812d..f20745f 100644
--- a/sources/include/citygml/featureobject.h
+++ b/sources/include/citygml/featureobject.h
@@ -9,7 +9,7 @@ namespace citygml {
 
     class Envelope;
 
-    class FeatureObject : public Object {
+    class LIBCITYGML_EXPORT FeatureObject : public Object {
     public:
         FeatureObject(const std::string& gmlID);
 
diff --git a/sources/include/citygml/geometry.h b/sources/include/citygml/geometry.h
index bb12435..e88e9ed 100644
--- a/sources/include/citygml/geometry.h
+++ b/sources/include/citygml/geometry.h
@@ -88,6 +88,6 @@ namespace citygml {
         std::vector<std::shared_ptr<LineString> > m_lineStrings;
     };
 
-    std::ostream& operator<<( std::ostream& os, const citygml::Geometry& s );
+    LIBCITYGML_EXPORT std::ostream& operator<<( std::ostream& os, const citygml::Geometry& s );
 
 }
diff --git a/sources/include/citygml/geometrymanager.h b/sources/include/citygml/geometrymanager.h
index 0e29b8c..0a144ad 100644
--- a/sources/include/citygml/geometrymanager.h
+++ b/sources/include/citygml/geometrymanager.h
@@ -5,13 +5,15 @@
 #include <unordered_map>
 #include <vector>
 
+#include <citygml/citygml_api.h>
+
 namespace citygml {
 
     class ImplicitGeometry;
     class Geometry;
     class CityGMLLogger;
 
-    class GeometryManager {
+    class LIBCITYGML_EXPORT GeometryManager {
     public:
         GeometryManager(std::shared_ptr<CityGMLLogger> logger);
 
diff --git a/sources/include/citygml/implictgeometry.h b/sources/include/citygml/implictgeometry.h
index 8fe8282..0b6113e 100644
--- a/sources/include/citygml/implictgeometry.h
+++ b/sources/include/citygml/implictgeometry.h
@@ -12,7 +12,7 @@ namespace citygml {
     class Geometry;
     class CityGMLFactory;
 
-    class ImplicitGeometry : public Object
+    class LIBCITYGML_EXPORT ImplicitGeometry : public Object
     {
         friend class CityGMLFactory;
     public:
diff --git a/sources/include/citygml/object.h b/sources/include/citygml/object.h
index a8eb302..81634a3 100644
--- a/sources/include/citygml/object.h
+++ b/sources/include/citygml/object.h
@@ -33,6 +33,6 @@ namespace citygml {
         AttributesMap m_attributes;
     };
 
-    std::ostream& operator<<( std::ostream&, const citygml::Object& );
+    LIBCITYGML_EXPORT std::ostream& operator<<( std::ostream&, const citygml::Object& );
 
 }
diff --git a/sources/include/citygml/polygonmanager.h b/sources/include/citygml/polygonmanager.h
index b8a45de..8ff3ca5 100644
--- a/sources/include/citygml/polygonmanager.h
+++ b/sources/include/citygml/polygonmanager.h
@@ -5,13 +5,15 @@
 #include <unordered_map>
 #include <vector>
 
+#include <citygml/citygml_api.h>
+
 namespace citygml {
 
     class Polygon;
     class Geometry;
     class CityGMLLogger;
 
-    class PolygonManager {
+    class LIBCITYGML_EXPORT PolygonManager {
     public:
         PolygonManager(std::shared_ptr<CityGMLLogger> logger);
 
diff --git a/sources/include/citygml/tesselator.h b/sources/include/citygml/tesselator.h
index 397e9ee..e6b6e86 100644
--- a/sources/include/citygml/tesselator.h
+++ b/sources/include/citygml/tesselator.h
@@ -30,6 +30,7 @@
   #include <GL/glu.h>
 #endif
 
+#include <citygml/citygml_api.h>
 #include <citygml/vecs.hpp>
 #include <vector>
 #include <list>
@@ -40,7 +41,7 @@ namespace citygml {
 }
 
 // GLU based polygon tesselator
-class Tesselator
+class LIBCITYGML_EXPORT Tesselator
 {
 public:
     Tesselator( std::shared_ptr<citygml::CityGMLLogger> logger );
diff --git a/sources/include/citygml/texture.h b/sources/include/citygml/texture.h
index 7afe134..b01b72f 100644
--- a/sources/include/citygml/texture.h
+++ b/sources/include/citygml/texture.h
@@ -17,10 +17,10 @@ namespace citygml {
         enum class WrapMode
         {
             WM_NONE,        // the resulting color is fully transparent
-            WM_WRAP,		// the texture is repeated
-            WM_MIRROR,		// the texture is repeated and mirrored
-            WM_CLAMP,		// the texture is clamped to its edges
-            WM_BORDER		// the resulting color is specified by the borderColor element (RGBA)
+            WM_WRAP,        // the texture is repeated
+            WM_MIRROR,      // the texture is repeated and mirrored
+            WM_CLAMP,       // the texture is clamped to its edges
+            WM_BORDER       // the resulting color is specified by the borderColor element (RGBA)
         };
 
         std::string getUrl() const;
diff --git a/sources/include/citygml/texturecoordinates.h b/sources/include/citygml/texturecoordinates.h
index a6a4cf6..27c05db 100644
--- a/sources/include/citygml/texturecoordinates.h
+++ b/sources/include/citygml/texturecoordinates.h
@@ -15,7 +15,7 @@ namespace citygml {
     /**
      * @brief The TextureCoordinates class describes a mapping of texture coordinates to the vertices of a linear ring
      */
-    class TextureCoordinates : public Object {
+    class LIBCITYGML_EXPORT TextureCoordinates : public Object {
     public:
         TextureCoordinates(std::string id, std::string targetID);
 
diff --git a/sources/include/citygml/transformmatrix.h b/sources/include/citygml/transformmatrix.h
index 787f16b..48b8a76 100644
--- a/sources/include/citygml/transformmatrix.h
+++ b/sources/include/citygml/transformmatrix.h
@@ -4,7 +4,7 @@
 #include <memory>
 
 namespace citygml {
-    class TransformationMatrix : public Object
+    class LIBCITYGML_EXPORT TransformationMatrix : public Object
     {
     public:
         TransformationMatrix();

diff --git a/sources/include/citygml/enum_type_bitmask.h b/sources/include/citygml/enum_type_bitmask.h
index e056db2..7ea0917 100644
--- a/sources/include/citygml/enum_type_bitmask.h
+++ b/sources/include/citygml/enum_type_bitmask.h
@@ -4,8 +4,10 @@
 #include <istream>
 #include <ostream>
 
+#include <citygml/citygml_api.h>
+
 template <typename T>
-class EnumClassBitmask
+class LIBCITYGML_EXPORT EnumClassBitmask
 {
 private:
     T t;
@@ -39,15 +41,15 @@ public:
 };
 
 #define ENUM_CLASS_BITWISE_OPERATORS(type_name) \
 /*constexpr*/ type_name operator|(type_name l, type_name r) { return type_name(std::underlying_type<type_name>::type(l) | std::underlying_type<type_name>::type(r)); } \
 /*constexpr*/ type_name operator&(type_name l, type_name r) { return type_name(std::underlying_type<type_name>::type(l) & std::underlying_type<type_name>::type(r)); } \
 /*constexpr*/ type_name operator^(type_name l, type_name r) { return type_name(std::underlying_type<type_name>::type(l) ^ std::underlying_type<type_name>::type(r)); } \
 /*constexpr*/ type_name operator~(type_name l) { return type_name(~std::underlying_type<type_name>::type(l)); }
 
 #define ENUM_CLASS_BITWISE_OPERATORS_DEFS(type_name) \
-/*constexpr*/ type_name operator|(type_name l, type_name r); \
-/*constexpr*/ type_name operator&(type_name l, type_name r); \
-/*constexpr*/ type_name operator^(type_name l, type_name r);\
-/*constexpr*/ type_name operator~(type_name l);
+/*constexpr*/ LIBCITYGML_EXPORT type_name operator|(type_name l, type_name r); \
+/*constexpr*/ LIBCITYGML_EXPORT type_name operator&(type_name l, type_name r); \
+/*constexpr*/ LIBCITYGML_EXPORT type_name operator^(type_name l, type_name r);\
+/*constexpr*/ LIBCITYGML_EXPORT type_name operator~(type_name l);
 
 
@@ -39,15 +41,15 @@ public:
 
 #define ENUM_CLASS_BITWISE_OPERATORS(type_name) \
-/*constexpr*/ type_name operator|(type_name l, type_name r) { return type_name(std::underlying_type<type_name>::type(l) | std::underlying_type<type_name>::type(r)); } \
-/*constexpr*/ type_name operator&(type_name l, type_name r) { return type_name(std::underlying_type<type_name>::type(l) & std::underlying_type<type_name>::type(r)); } \
-/*constexpr*/ type_name operator^(type_name l, type_name r) { return type_name(std::underlying_type<type_name>::type(l) ^ std::underlying_type<type_name>::type(r)); } \
-/*constexpr*/ type_name operator~(type_name l) { return type_name(~std::underlying_type<type_name>::type(l)); }
+/*constexpr*/ LIBCITYGML_EXPORT type_name operator|(type_name l, type_name r) { return type_name(std::underlying_type<type_name>::type(l) | std::underlying_type<type_name>::type(r)); } \
+/*constexpr*/ LIBCITYGML_EXPORT type_name operator&(type_name l, type_name r) { return type_name(std::underlying_type<type_name>::type(l) & std::underlying_type<type_name>::type(r)); } \
+/*constexpr*/ LIBCITYGML_EXPORT type_name operator^(type_name l, type_name r) { return type_name(std::underlying_type<type_name>::type(l) ^ std::underlying_type<type_name>::type(r)); } \
+/*constexpr*/ LIBCITYGML_EXPORT type_name operator~(type_name l) { return type_name(~std::underlying_type<type_name>::type(l)); }
 
 #define ENUM_CLASS_BITWISE_OPERATORS_DEFS(type_name) \
-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/pkg-grass/libcitygml.git



More information about the Pkg-grass-devel mailing list